## -- load data from the supplementary table 1 of the comments by Singh et al --
sd1 <- read.table(file = "supdata_1.txt", header = T, as.is = TRUE, sep = "\t", row.names = 1);
colnames( sd1 ) <- c( "symbol", "WGD", "SSD", "youngSSD", "WGDoldSSD", "oldSSD", "cancer", "cancer2", "Disease", "DiseaseType", "Haplo", "DominantNegative", "EssMouse", "AutoI", "Chen" );

## -- load necessary R functions --

dostats2 <- function( df, colAll = "all", colF = "monogenic" ){
    r <- c();
    
    for( c in c("oldSSDs", "WGDsOnly", "youngSSDs", "Singletons") ){
        m <- matrix( c( df[ c, colF ], 
                        df[c, colAll ] - df[ c, colF ],
                        df[ "all", colF ], 
                        df[ "all", colAll ] - df[ "all", colF ]), nrow = 2 );
        
        r <- rbind(r,  c(unlist(fisher.test( m )[ c("estimate", "p.value") ] ), m[, 1] / rowSums(m) * 100 ) );
    }
    
    ## -- old, wgd, young versus singletons --
    for( c in c("oldSSDs", "WGDsOnly", "youngSSDs") ){
        m <- matrix( c( df[ c, colF ], 
                        df[ c, colAll ] - df[ c, colF ],
                        df[ "Singletons", colF ], 
                        df[ "Singletons", colAll ] - df[ "Singletons", colF ]), nrow = 2 );
        r <- rbind(r,  c( unlist(fisher.test( m )[ c("estimate", "p.value") ] ), m[, 1] / rowSums(m) * 100 ) );
        
    }
    
    rownames( r ) <- c( paste( c(  "oldSSDs", "WGDsOnly", "youngSSDs", "Singletons" ), "vs.", colAll  ),
                        paste( c(  "oldSSDs", "WGDsOnly", "youngSSDs" ), "vs. Singletons"  ));
    
    return (r);
};

dostats <- function( df ){
    r <- c();
    r[1] <- dim(df)[1];## -- all  
    r[2] <- dim( df[ df$WGD == "Y",  ] )[1];
    r[3] <- dim( df[ df$WGD == "Y" & df$SSD == "N",  ] )[1];
    r[4] <- dim( df[ df$WGD == "N" & df$youngSSD == "Y",  ] )[1];
    r[5] <- dim( df[ df$WGD == "N" & df$oldSSD == "Y",  ] )[1];
    r[6] <- dim( df[ df$WGD == "N" & df$SSD == "N",  ] )[1];
    r[7] <- dim( df[ df$Chen != "N",  ] )[1]; ## -- monogenic 
    r[8] <- dim( df[ df$Chen == "AD",  ] )[1];
    r[9] <- dim( df[ df$Chen == "AR",  ] )[1];
    return(r);
}

## -- created on Feb 7, 2012 --
addConfidentOnTopOfPlot <- function( x, y, yrange, pvalues, dir = "left", incr = 0.02, dist = 0.04, col = "black", pvalue.cex = 0.5 ){
    ## -- parameters --
    ## x = numeric vector contains coordinate on x-axis --
    ## y = numeric vector contains coordinate on y-axis --
    ## yrange = ylim[2] - ylim[1] of current plot
    ## pvalues = numeric pvalues
    
    conf.strings <- as.character(symnum( pvalues, corr = FALSE, na = FALSE, cutpoints = c(0, 0.001, 0.01, 0.05, 1), symbols = c("***", "**", "*", " ")));
    
    if( dir != "left" ){
        x = rev(x);
        y = rev(y);
        conf.strings = rev(conf.strings);
    }
    ## -- start --
    i <- 1;
    len <- length(conf.strings);
    y1 <- 0;
    y2 <- 0;
    y3 <- 0;
    
    while( i <= length(conf.strings) ){
        
        ## -- plot --
        if( i == 1 ){
            y1 <- y[i] + yrange * dist;
        } else {
            y1 <- max( y1, y2, y3 ) + yrange * dist;
        }
        
        y2 <- y[ i + 1 ] + yrange * dist;
        y3 <- max( c( y[ i ], y[i + 1], y2, y1 ) + yrange * ( incr + dist ) )
        x1 <- x[i];
        x2 <- x[i + 1];
        segments( x1, y1, x1, y3, col = col ); ## vertical line 1
        segments( x2, y2, x2, y3 , col = col); ## vertical line 2
        segments( x1, y3, x2, y3 , col = col); ## horiz line 
        
        xsig <- x1 + (x2 - x1 ) / 2;
        ysig <- y3 + yrange * dist;
        
        text( xsig, ysig, paste( formatC(pvalues, digits=3), as.character( conf.strings[i] ) ) , cex = pvalue.cex);
        
        print(conf.strings[i]);
        
        ## at the end, increase i
        i <- i + 1;
    }
}

## -- input vec = a vector contains four values, 1 = OR, 2 = p value, 3 = %, 4 = %
plotAPanel <- function( vec, label, col, names ){
    b <- barplot( vec[c(3,4)], las = 1, col = col, border=NA, ylim = c(0, max(vec[c(3,4)] ) * 1.2));
    addConfidentOnTopOfPlot( unlist(b),  vec[c(3,4)], yrange = max(  vec[c(3,4)] ), vec[2], pvalue.cex=1 );
    text( unlist(b), c(0, 0), col = "black", pos = 4, srt = 90, labels = paste( round( vec[c(3,4)], digits=2 ), "%", sep = ""), adj = 1 );
    mtext(paste( "OR=", round( vec[1], digits=2 ) ), side = 3, adj = 0.5, line = 0.5, cex = 0.5);
    mtext( label , side = 3, adj = -0.1, line = 1);
}

#################################################
## -- get data ready --
stats <- data.frame( all = dostats(sd1), 
                     monogenic = dostats( sd1[ sd1$Chen != "N",  ] ),
                     AD = dostats( sd1[ sd1$Chen == "AD",  ] ),
                     nonAD = dostats( sd1[ sd1$Chen != "N" & sd1$Chen != "AD",  ] ),
                     ADnonHaplo = dostats( sd1[ sd1$Chen == "AD" & sd1$Haplo == "N",  ] ),
                     AR = dostats( sd1[ sd1$Chen == "AR",  ] ),
                     nonAR = dostats( sd1[ sd1$Chen != "N" & sd1$Chen != "AR",  ] ),
                     ARnonHaplo = dostats( sd1[ sd1$Chen == "AR" & sd1$Haplo == "N",  ] ),
                     testedEss = dostats( sd1[ sd1$EssMouse != "O",  ] ),
                     testedEssNonAD = dostats( sd1[ sd1$EssMouse != "O" & sd1$Chen != "AD",  ] ),
                     Ess = dostats( sd1[ sd1$EssMouse == "Y", ] ),
                     EssNonAD = dostats( sd1[ sd1$EssMouse == "Y" & sd1$Chen != "AD", ] ) );

rownames(stats) <- c("all", "WGDs", "WGDsOnly", "youngSSDs", "oldSSDs", "Singletons", "monogenic", "AD", "AR" );

## -- plot --
## -- 
pdf(file = "figure1.pdf", height = 4, width = 6);
par(mfcol=c(1,4));
a <- dostats2( stats, colAll = "all", colF = "monogenic" );
plotAPanel( a[1,], label = "A" , col = c("blue"));

b <- dostats2( stats, colAll = "monogenic", colF = "AR"  );
plotAPanel( b[1,], label = "B" , col = c("green"));

c <- dostats2( stats, colAll = "testedEss", colF = "Ess" );
plotAPanel( c[3,], label = "C" , col = c("red" ));
plotAPanel( c[1,], label = "D" , col = c("purple"));
dev.off();

## -- how many genes that Singh et al used overlap with the mouse essentiality data ?? --
sum( table( sd1$EssMouse[ sd1$Chen %in% c("AD", "AR") ] )[ c("Y", "N") ] );

## -- how many of the mouse essential genes are essential in human ??? --
## -- using data from the sup file 1 of Chen et al Plos CB : 
## -- download a zip file from : http://www.ploscompbiol.org/article/fetchSingleRepresentation.action?uri=info:doi/10.1371/journal.pcbi.1003073.s009
## -- unzip it, load the file "DATA_DUP_BY_TREEFAM_ALL.txt" (included here already)
dat <- read.table(file = "DATA_DUP_BY_TREEFAM_ALL.txt", header = T, as.is = T, sep = "\t", row.names = 1);
## -- you will find two relavent columns:
## -- ess = mouse enssential genes (N = tested but not essential; Y = tested and essential; NA = not tested)
## -- essHuman = human essential genes; can be obtained from http://ogeedb.embl.de/#summary; original publication : http://www.ncbi.nlm.nih.gov/pubmed/18239125
## -- now count --
table( dat$ess[dat$essHuman == "Y"] ); 
table( dat$essHuman[dat$ess == "Y"] ); 

